summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMiles Bader <miles@gnu.org>1996-04-10 00:20:58 +0000
committerMiles Bader <miles@gnu.org>1996-04-10 00:20:58 +0000
commit7bd983614d31efa64302228cb36a0bf224159e34 (patch)
tree7c33eec05bc2909243c7e3486ed389dd7311c151
parent45a873a8d2c464f5dd97229665d361fb88e4eff4 (diff)
(diskfs_enter_lookup_cache, diskfs_purge_lookup_cache,
diskfs_check_lookup_cache): Renamed from versions without `lookup_'.
-rw-r--r--libdiskfs/diskfs.h11
1 files changed, 5 insertions, 6 deletions
diff --git a/libdiskfs/diskfs.h b/libdiskfs/diskfs.h
index 4a06f47d..8ac89101 100644
--- a/libdiskfs/diskfs.h
+++ b/libdiskfs/diskfs.h
@@ -907,9 +907,8 @@ error_t diskfs_dirrewrite (struct node *dp, struct node *oldnp,
error_t diskfs_dirremove (struct node *dp, struct node *np,
char *name, struct dirstat *ds);
-/* Return the node corresponding to CACHE_ID. Return null
- if no such node exists. */
-struct node *diskfs_cached_lookup (int cache_id);
+/* Return the node corresponding to CACHE_ID in *NPP. */
+error_t diskfs_cached_lookup (int cache_id, struct node **npp);
/* Create a new node. Give it MODE; if that includes IFDIR, also
initialize `.' and `..' in the new directory. Return the node in NPP.
@@ -958,17 +957,17 @@ void diskfs_release_peropen (struct peropen *po);
/* Node NP has just been found in DIR with NAME. If NP is null, that
means that this name has been confirmed as absent in the directory. */
-void diskfs_enter_cache (struct node *dir, struct node *np, char *name);
+void diskfs_enter_lookup_cache (struct node *dir, struct node *np, char *name);
/* Purge all references in the cache to NP as a node inside
directory DP. */
-void diskfs_purge_cache (struct node *dp, struct node *np);
+void diskfs_purge_lookup_cache (struct node *dp, struct node *np);
/* Scan the cache looking for NAME inside DIR. If we don't know
anything entry at all, then return 0. If the entry is confirmed to
not exist, then return -1. Otherwise, return NP for the entry, with
a newly allocated reference. */
-struct node *diskfs_check_cache (struct node *dir, char *name);
+struct node *diskfs_check_lookup_cache (struct node *dir, char *name);
/* Rename directory node FNP (whose parent is FDP, and which has name
FROMNAME in that directory) to have name TONAME inside directory